==> dfiber-0.1.1-py3-none-any.whl: dfiber/core/aqua.py <==
import logging

import pandas as pd
import trino
from trino.exceptions import TrinoConnectionError, TrinoDataError, \
    TrinoQueryError, TrinoUserError, \
    TrinoInternalError, TrinoExternalError, \
    DatabaseError, OperationalError

from dfiber.core.dfiber_exceptions import DfiberConnectionException, \
    DfiberException, \
    DfiberQueryException, DfiberOperationException


class _Aqua:
    """
    This class is used by Dfiber to connect to dview's services and execute queries

    Attributes:
        connection_args (dict): Aqua connection arguments.
    """

    def __init__(self, connection_args: dict):
        """
        Initialize Aqua instance

        Args:
            connection_args (dict): Aqua connection arguments.
        """
        self.connection_args = connection_args
        self.connection = None

    def _connect(self):
        """
        Establish a connection to the Dfiber endpoint.

        Returns:
            Connection Object: A connection object to the Dfiber endpoint.

        Raises:
            DfiberConnectionException: If connection to Dfiber fails.
            DfiberException: If any other unexpected error occurs.
        """
        try:
            connection = trino.dbapi.connect(**self.connection_args)
            logging.info("Connected to Dfiber successfully.")
            return connection
        except (TrinoConnectionError, TrinoDataError, ConnectionError, OSError) as e:
            error_type = getattr(e, 'error_type', 'CONNECTION_ERROR')
            name = "DFIBER_CONNECTION_FAILED"
            message = getattr(e, 'message', str(e))
            raise DfiberConnectionException(error_type=error_type, name=name, detail=f"Failed to connect to Dfiber - {message}")
        except Exception as e:
            error_type = getattr(e, 'error_name', type(e).__name__)
            error_name = getattr(e, 'error_name', e.__class__.__name__)
            message = getattr(e, 'message', str(e))
            raise DfiberException(error_type=error_type, name=error_name, detail=f"Unexpected error - {message}")

    def execute_query(self, query):
        """
        Executes a SQL query on the Dfiber server and returns the result as a pandas DataFrame to Dfiber.

        Args:
            query (str): The SQL query to execute.

        Returns:
            pd.DataFrame: A pandas DataFrame containing the query results from Dfiber.

        Raises:
            DfiberConnectionException: If the connection to Dfiber fails.
            DfiberQueryException: If the query execution fails.
            DfiberOperationException: If an unexpected error occurs during query execution.
            DfiberFiberException: If an unknown or unhandled error occurs.
        """

        if self.connection is None:
            self.connection = self._connect()

        try:
            cursor = self.connection.cursor()
            cursor.execute(query)
            rows = cursor.fetchall()

            columns = [desc[0] for desc in cursor.description]
            return pd.DataFrame(rows, columns=columns)
        except TrinoConnectionError as e:
            raise DfiberConnectionException(error_type="CONNECTION_ERROR",
                                            name="DFIBER_CONNECTION_FAILED",
                                            detail=f"Failed to connect to Dfiber - {getattr(e, 'message', str(e))}")
        except (TrinoQueryError, TrinoDataError, TrinoUserError) as e:
            error_type = getattr(e, 'error_type', 'QUERY_ERROR')
            name = getattr(e, 'error_name', 'DFIBER_QUERY_EXECUTION_FAILED')
            message = getattr(e, 'message', str(e))
            raise DfiberQueryException(error_type=error_type, name=name, detail=f"Dfiber query error - {message}")
        except (TrinoInternalError, TrinoExternalError, OperationalError, DatabaseError) as e:
            error_type = getattr(e, 'error_type', 'OPERATION_ERROR')
            name = getattr(e, 'error_name', 'DFIBER_SERVICE_UNAVAILABLE')
            message = getattr(e, 'message', str(e))
            raise DfiberOperationException(error_type=error_type, name=name, detail=f"Dfiber internal error - {message}")
        except Exception as e:
            error_type = getattr(e, 'error_type', type(e).__name__)
            error_name = getattr(e, 'error_name', e.__class__.__name__)
            message = getattr(e, 'message', str(e))
            raise DfiberException(error_type=error_type, name=error_name, detail=f"Unexpected error - {message}")
        finally:
            if self.connection is not None:
                self.connection.close()

==> dfiber-0.1.2-py3-none-any.whl: dfiber/core/aqua.py <==
import logging

import pandas as pd
import trino
from trino.exceptions import TrinoConnectionError, TrinoDataError, \
    TrinoQueryError, TrinoUserError, \
    TrinoInternalError, TrinoExternalError, \
    DatabaseError, OperationalError

from dfiber.core.dfiber_exceptions import DfiberConnectionException, \
    DfiberException, \
    DfiberQueryException, DfiberOperationException


class _Aqua:
    """
    This class is used by Dfiber to connect to dview's services and execute queries

    Attributes:
        connection_args (dict): Aqua connection arguments.
    """

    def __init__(self, connection_args: dict):
        """
        Initialize Aqua instance

        Args:
            connection_args (dict): Aqua connection arguments.
        """
        self._connection_args = connection_args
        self.connection = None

    def _connect(self):
        """
        Establish a connection to the Dfiber endpoint.

        Returns:
            Connection Object: A connection object to the Dfiber endpoint.

        Raises:
            DfiberConnectionException: If connection to Dfiber fails.
            DfiberException: If any other unexpected error occurs.
        """
        try:
            connection = trino.dbapi.connect(**self._connection_args)
            logging.info("Connected to Dfiber successfully.")
            return connection
        except (TrinoConnectionError, TrinoDataError, ConnectionError, OSError) as e:
            error_type = getattr(e, 'error_type', 'CONNECTION_ERROR')
            name = "DFIBER_CONNECTION_FAILED"
            message = getattr(e, 'message', str(e))
            raise DfiberConnectionException(error_type=error_type, name=name, detail=f"Failed to connect to Dfiber - {message}")
        except Exception as e:
            error_type = getattr(e, 'error_name', type(e).__name__)
            error_name = getattr(e, 'error_name', e.__class__.__name__)
            message = getattr(e, 'message', str(e))
            raise DfiberException(error_type=error_type, name=error_name, detail=f"Unexpected error - {message}")

    def execute_query(self, query):
        """
        Executes a SQL query on the Dfiber server and returns the result as a pandas DataFrame to Dfiber.

        Args:
            query (str): The SQL query to execute.

        Returns:
            pd.DataFrame: A pandas DataFrame containing the query results from Dfiber.

        Raises:
            DfiberConnectionException: If the connection to Dfiber fails.
            DfiberQueryException: If the query execution fails.
            DfiberOperationException: If an unexpected error occurs during query execution.
            DfiberFiberException: If an unknown or unhandled error occurs.
        """

        if self.connection is None:
            self.connection = self._connect()

        try:
            cursor = self.connection.cursor()
            cursor.execute(query)
            rows = cursor.fetchall()

            columns = [desc[0] for desc in cursor.description]
            return pd.DataFrame(rows, columns=columns)
        except TrinoConnectionError as e:
            raise DfiberConnectionException(error_type="CONNECTION_ERROR",
                                            name="DFIBER_CONNECTION_FAILED",
                                            detail=f"Failed to connect to Dfiber - {getattr(e, 'message', str(e))}")
        except (TrinoQueryError, TrinoDataError, TrinoUserError) as e:
            error_type = getattr(e, 'error_type', 'QUERY_ERROR')
            name = getattr(e, 'error_name', 'DFIBER_QUERY_EXECUTION_FAILED')
            message = getattr(e, 'message', str(e))
            raise DfiberQueryException(error_type=error_type, name=name, detail=f"Dfiber query error - {message}")
        except (TrinoInternalError, TrinoExternalError, OperationalError, DatabaseError) as e:
            error_type = getattr(e, 'error_type', 'OPERATION_ERROR')
            name = getattr(e, 'error_name', 'DFIBER_SERVICE_UNAVAILABLE')
            message = getattr(e, 'message', str(e))
            raise DfiberOperationException(error_type=error_type, name=name, detail=f"Dfiber internal error - {message}")
        except Exception as e:
            error_type = getattr(e, 'error_type', type(e).__name__)
            error_name = getattr(e, 'error_name', e.__class__.__name__)
            message = getattr(e, 'message', str(e))
            raise DfiberException(error_type=error_type, name=error_name, detail=f"Unexpected error - {message}")
        finally:
            if self.connection is not None:
                self.connection.close()
